@@ -142,7 +142,7 @@ to set the pitch of A-4, from which the rest is calculated."""
 
 		# int(Note("A")) == 57
 		diff = self.__int__() - 57
-		return 2 ** (diff / 12) * 440
+		return 2 ** (diff / 12.0) * 440
 
 	def from_hertz(self, hertz, standard_pitch = 440):
 		"""Sets the Note name and pitch, calculated from the `hertz` value. \
